import { isValidChecksumAddress, stripHexPrefix, toChecksumAddress, } from 'crypto-addr-codec';
import { bech32 } from 'bech32';
function makeChecksummedHexDecoder(chainId) {
    return (data) => {
        const stripped = stripHexPrefix(data);
        if (!isValidChecksumAddress(data, chainId || null) &&
            stripped !== stripped.toLowerCase() &&
            stripped !== stripped.toUpperCase()) {
            throw Error('Invalid address checksum');
        }
        return Buffer.from(stripHexPrefix(data), 'hex');
    };
}
function makeChecksummedHexEncoder(chainId) {
    return (data) => toChecksumAddress(data.toString('hex'), chainId || null);
}
const hexChecksumChain = (name, chainId) => ({
    decoder: makeChecksummedHexDecoder(chainId),
    encoder: makeChecksummedHexEncoder(chainId),
    name,
});
export const ETH = hexChecksumChain('ETH');
function makeBech32Encoder(prefix) {
    return (data) => bech32.encode(prefix, bech32.toWords(data));
}
function makeBech32Decoder(currentPrefix) {
    return (data) => {
        const { prefix, words } = bech32.decode(data);
        if (prefix !== currentPrefix) {
            throw Error('Unrecognised address format');
        }
        return Buffer.from(bech32.fromWords(words));
    };
}
const bech32Chain = (name, prefix) => ({
    decoder: makeBech32Decoder(prefix),
    encoder: makeBech32Encoder(prefix),
    name,
});
export const ETHERMINT = bech32Chain('ETHERMINT', 'ethm');
export const ethToEthermint = (ethAddress) => {
    const data = ETH.decoder(ethAddress);
    return ETHERMINT.encoder(data);
};
export const ethermintToEth = (ethermintAddress) => {
    const data = ETHERMINT.decoder(ethermintAddress);
    return ETH.encoder(data);
};
export const EVMOS = bech32Chain('EVMOS', 'evmos');
export const ethToEvmos = (ethAddress) => {
    const data = ETH.decoder(ethAddress);
    return EVMOS.encoder(data);
};
export const evmosToEth = (evmosAddress) => {
    const data = EVMOS.decoder(evmosAddress);
    return ETH.encoder(data);
};
export const OSMOSIS = bech32Chain('OSMOSIS', 'osmo');
export const ethToOsmosis = (ethAddress) => {
    const data = ETH.decoder(ethAddress);
    return OSMOSIS.encoder(data);
};
export const osmosisToEth = (evmosAddress) => {
    const data = OSMOSIS.decoder(evmosAddress);
    return ETH.encoder(data);
};
export const COSMOS = bech32Chain('COSMOS', 'cosmos');
export const ethToCosmos = (ethAddress) => {
    const data = ETH.decoder(ethAddress);
    return COSMOS.encoder(data);
};
export const cosmosToEth = (evmosAddress) => {
    const data = COSMOS.decoder(evmosAddress);
    return ETH.encoder(data);
};
export const KYVE = bech32Chain('KORELLIA', 'kyve');
export const ethToKyve = (ethAddress) => {
    const data = ETH.decoder(ethAddress);
    return KYVE.encoder(data);
};
export const kyveToEth = (kyveAddress) => {
    const data = KYVE.decoder(kyveAddress);
    return ETH.encoder(data);
};
export const AKASH = bech32Chain('AKASH', 'akash');
export const ethToAkash = (ethAddress) => {
    const data = ETH.decoder(ethAddress);
    return AKASH.encoder(data);
};
export const akashToEth = (akashAddress) => {
    const data = AKASH.decoder(akashAddress);
    return ETH.encoder(data);
};
//# sourceMappingURL=converter.js.map